diff jvmci/jdk.vm.ci.hotspot/src/jdk/vm/ci/hotspot/VMField.java @ 24106:1439a6614a10

8174957: [JVMCI] jaotc is broken in Xcomp mode
author Doug Simon <doug.simon@oracle.com>
date Wed, 15 Feb 2017 15:36:48 +0100
parents b5557b757040
children
line wrap: on
line diff
--- a/jvmci/jdk.vm.ci.hotspot/src/jdk/vm/ci/hotspot/VMField.java	Tue Feb 14 23:11:04 2017 +0100
+++ b/jvmci/jdk.vm.ci.hotspot/src/jdk/vm/ci/hotspot/VMField.java	Wed Feb 15 15:36:48 2017 +0100
@@ -38,22 +38,22 @@
     public final String type;
 
     /**
-     * If represented field is non-static, this is its offset within the containing structure.
+     * If the represented field is non-static, this is its offset within the containing structure.
      */
     public final long offset;
 
     /**
-     * If represented field is static, this is its address. Otherwise, this field is 0.
+     * If the represented field is static, this is its address. Otherwise, this is 0.
      */
     public final long address;
 
     /**
      * Value of the field represented as a boxed long; only valid for non-oop static fields. This
      * value is only captured once, during JVMCI initialization. If {@link #type} cannot be
      * meaningfully (e.g., a struct) or safely (e.g., an oop) expressed as a boxed long, this is
      * {@code null}.
      */
-    public final Long value;
+    public final Object value;
 
     /**
      * Determines if the represented field is static.
@@ -38,22 +38,22 @@
 
     /**
-     * Value of the field represented as a boxed long; only valid for non-oop static fields. This
-     * value is only captured once, during JVMCI initialization. If {@link #type} cannot be
-     * meaningfully (e.g., a struct) or safely (e.g., an oop) expressed as a boxed long, this is
-     * {@code null}.
+     * Value of the field represented as a boxed boolean if its C++ type is bool otherwise as a
+     * boxed long; only valid for non-oop static fields. This value is only captured once, during
+     * JVMCI initialization. If {@link #type} cannot be meaningfully (e.g., a struct) or safely
+     * (e.g., an oop) expressed as a boxed object, this is {@code null}.
      */